@@ -55,6 +55,18 @@ if (VIDEOS["AM8052"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/ariel.h,VIDEOS["ARIEL"] = true
+--------------------------------------------------
+
+if (VIDEOS["ARIEL"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/ariel.cpp",
+		MAME_DIR .. "src/devices/video/ariel.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/atirage.h,VIDEOS["ATIRAGE"] = true
@@ -199,6 +211,18 @@ if (VIDEOS["DP8350"]~=null) then
 	}
 end
 
+---------------------------------------------------
+--
+--@src/devices/video/ds8874.h,VIDEOS["DS8874"] = true
+---------------------------------------------------
+
+if (VIDEOS["DS8874"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/ds8874.cpp",
+		MAME_DIR .. "src/devices/video/ds8874.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/ef9340_1.h,VIDEOS["EF9340_1"] = true
@@ -247,28 +271,6 @@ if (VIDEOS["EF9365"]~=null) then
 	}
 end
 
---------------------------------------------------
---@src/devices/video/epic12.h,VIDEOS["EPIC12"] = true
---------------------------------------------------
-
-if (VIDEOS["EPIC12"]~=null) then
-	files {
-		MAME_DIR .. "src/devices/video/epic12.cpp",
-		MAME_DIR .. "src/devices/video/epic12.h",
-		MAME_DIR .. "src/devices/video/epic12_blit0.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit1.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit2.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit3.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit4.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit5.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit6.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit7.cpp",
-		MAME_DIR .. "src/devices/video/epic12_blit8.cpp",
-		MAME_DIR .. "src/devices/video/epic12in.hxx",
-		MAME_DIR .. "src/devices/video/epic12pixel.hxx",
-	}
-end
-
 --------------------------------------------------
 --
 --@src/devices/video/fixfreq.h,VIDEOS["FIXFREQ"] = true
@@ -305,18 +307,6 @@ if (VIDEOS["GF7600GS"]~=null) then
 	}
 end
 
---------------------------------------------------
---
---@src/devices/video/mga2064w.h,VIDEOS["MGA2064W"] = true
---------------------------------------------------
-
-if (VIDEOS["MGA2064W"]~=null) then
-	files {
-		MAME_DIR .. "src/devices/video/mga2064w.cpp",
-		MAME_DIR .. "src/devices/video/mga2064w.h",
-	}
-end
-
 --------------------------------------------------
 --
 --@src/devices/video/nt7534.h,VIDEOS["NT7534"] = true
@@ -377,6 +367,18 @@ if (VIDEOS["HD61202"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/hd61602.h,VIDEOS["HD61602"] = true
+--------------------------------------------------
+
+if (VIDEOS["HD61602"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/hd61602.cpp",
+		MAME_DIR .. "src/devices/video/hd61602.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/hd61603.h,VIDEOS["HD61603"] = true
@@ -631,13 +633,13 @@ end
 
 --------------------------------------------------
 --
---@src/devices/video/lc7582.h,VIDEOS["LC7582"] = true
+--@src/devices/video/lc7580.h,VIDEOS["LC7580"] = true
 --------------------------------------------------
 
-if (VIDEOS["LC7582"]~=null) then
+if (VIDEOS["LC7580"]~=null) then
 	files {
-		MAME_DIR .. "src/devices/video/lc7582.cpp",
-		MAME_DIR .. "src/devices/video/lc7582.h",
+		MAME_DIR .. "src/devices/video/lc7580.cpp",
+		MAME_DIR .. "src/devices/video/lc7580.h",
 	}
 end
 
@@ -665,6 +667,18 @@ if (VIDEOS["M50458"]~=null) then
 	}
 end
 
+---------------------------------------------------
+--
+--@src/devices/video/mb86292.h,VIDEOS["MB86292"] = true
+---------------------------------------------------
+
+if (VIDEOS["MB86292"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/mb86292.cpp",
+		MAME_DIR .. "src/devices/video/mb86292.h",
+	}
+end
+
 ---------------------------------------------------
 --
 --@src/devices/video/mb88303.h,VIDEOS["MB88303"] = true
@@ -761,6 +775,18 @@ if (VIDEOS["MM5445"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/mr9735.h,VIDEOS["MR9735"] = true
+--------------------------------------------------
+
+if (VIDEOS["MR9735"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/mr9735.cpp",
+		MAME_DIR .. "src/devices/video/mr9735.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/msm6222b.h,VIDEOS["MSM6222B"] = true
@@ -809,6 +835,18 @@ if (VIDEOS["MOS8563"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/mn1252.h,VIDEOS["MN1252"] = true
+--------------------------------------------------
+
+if (VIDEOS["MN1252"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/mn1252.cpp",
+		MAME_DIR .. "src/devices/video/mn1252.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/pc_vga.h,VIDEOS["PC_VGA"] = true
@@ -818,25 +856,226 @@ if (VIDEOS["PC_VGA"]~=null) then
 	files {
 		MAME_DIR .. "src/devices/video/pc_vga.cpp",
 		MAME_DIR .. "src/devices/video/pc_vga.h",
-		MAME_DIR .. "src/devices/bus/isa/trident.cpp",
-		MAME_DIR .. "src/devices/bus/isa/trident.h",
-		MAME_DIR .. "src/devices/video/clgd542x.cpp",
-		MAME_DIR .. "src/devices/video/clgd542x.h",
 	}
 end
 
 --------------------------------------------------
 --
---@src/devices/video/virge_pci.h,VIDEOS["VIRGE_PCI"] = true
+--@src/devices/video/pc_vga_alliance.h,VIDEOS["PC_VGA_ALLIANCE"] = true
 --------------------------------------------------
 
-if (VIDEOS["VIRGE_PCI"]~=null) then
+if (VIDEOS["PC_VGA_ALLIANCE"]~=null) then
 	files {
-		MAME_DIR .. "src/devices/video/virge_pci.cpp",
-		MAME_DIR .. "src/devices/video/virge_pci.h",
+		MAME_DIR .. "src/devices/video/pc_vga_alliance.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_alliance.h",
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_ati.h,VIDEOS["PC_VGA_ATI"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_ATI"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_ati.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_ati.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/ibm8514a.h,VIDEOS["IBM8514A"] = true
+--------------------------------------------------
+
+if (VIDEOS["IBM8514A"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/ibm8514a.cpp",
+		MAME_DIR .. "src/devices/video/ibm8514a.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/ati_mach8.h,VIDEOS["ATI_MACH8"] = true
+--------------------------------------------------
+
+if (VIDEOS["ATI_MACH8"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/ati_mach8.cpp",
+		MAME_DIR .. "src/devices/video/ati_mach8.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/ati_mach8.h,VIDEOS["ATI_MACH32"] = true
+--------------------------------------------------
+
+if (VIDEOS["ATI_MACH32"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/ati_mach32.cpp",
+		MAME_DIR .. "src/devices/video/ati_mach32.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_cirrus.h,VIDEOS["PC_VGA_CIRRUS"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_CIRRUS"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_cirrus.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_cirrus.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_matrox.h,VIDEOS["PC_VGA_MATROX"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_MATROX"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_matrox.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_matrox.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_mediagx.h,VIDEOS["PC_VGA_MEDIAGX"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_MEDIAGX"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_mediagx.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_mediagx.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_nvidia.h,VIDEOS["PC_VGA_NVIDIA"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_NVIDIA"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_nvidia.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_nvidia.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_oak.h,VIDEOS["PC_VGA_OAK"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_OAK"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_oak.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_oak.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_paradise.h,VIDEOS["PC_VGA_PARADISE"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_PARADISE"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_paradise.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_paradise.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/wd90c26.h,VIDEOS["WD90C26"] = true
+--------------------------------------------------
+
+if (VIDEOS["WD90C26"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/wd90c26.cpp",
+		MAME_DIR .. "src/devices/video/wd90c26.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_s3.h,VIDEOS["PC_VGA_S3"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_S3"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_s3.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_s3.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/s3virge.h,VIDEOS["S3VIRGE"] = true
+--------------------------------------------------
+
+if (VIDEOS["S3VIRGE"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/s3virge.cpp",
+		MAME_DIR .. "src/devices/video/s3virge.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_sis.h,VIDEOS["PC_VGA_SIS"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_SIS"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_sis.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_sis.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_trident.h,VIDEOS["PC_VGA_TRIDENT"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_TRIDENT"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_trident.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_trident.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_vga_tseng.h,VIDEOS["PC_VGA_TSENG"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_VGA_TSENG"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_vga_tseng.cpp",
+		MAME_DIR .. "src/devices/video/pc_vga_tseng.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/pc_xga.h,VIDEOS["PC_XGA"] = true
+--------------------------------------------------
+
+if (VIDEOS["PC_XGA"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pc_xga.cpp",
+		MAME_DIR .. "src/devices/video/pc_xga.h",
+	}
+end
+
+
 --------------------------------------------------
 --
 --@src/devices/video/pcd8544.h,VIDEOS["PCD8544"] = true
@@ -909,6 +1148,18 @@ if (VIDEOS["SAA5240"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/saa7110.h,VIDEOS["SAA7110"] = true
+--------------------------------------------------
+
+if (VIDEOS["SAA7110"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/saa7110.cpp",
+		MAME_DIR .. "src/devices/video/saa7110.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/sn74s262.h,VIDEOS["SN74S262"] = true
@@ -1175,18 +1426,6 @@ if (VIDEOS["UPD7227"]~=null) then
 	}
 end
 
---------------------------------------------------
---
---@src/devices/video/vic4567.h,VIDEOS["VIC4567"] = true
---------------------------------------------------
-
-if (VIDEOS["VIC4567"]~=null) then
-	files {
-		MAME_DIR .. "src/devices/video/vic4567.cpp",
-		MAME_DIR .. "src/devices/video/vic4567.h",
-	}
-end
-
 --------------------------------------------------
 --
 --@src/devices/video/v9938.h,VIDEOS["V9938"] = true
@@ -1318,6 +1557,18 @@ if (VIDEOS["PPU2C0X"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/bt431.h,VIDEOS["BT431"] = true
+--------------------------------------------------
+
+if (VIDEOS["BT431"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/bt431.cpp",
+		MAME_DIR .. "src/devices/video/bt431.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/bt459.h,VIDEOS["BT459"] = true
@@ -1330,6 +1581,42 @@ if (VIDEOS["BT459"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/bt45x.h,VIDEOS["BT45X"] = true
+--------------------------------------------------
+
+if (VIDEOS["BT45X"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/bt45x.cpp",
+		MAME_DIR .. "src/devices/video/bt45x.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/bt47x.h,VIDEOS["BT47X"] = true
+--------------------------------------------------
+
+if (VIDEOS["BT47X"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/bt47x.cpp",
+		MAME_DIR .. "src/devices/video/bt47x.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/bt48x.h,VIDEOS["BT48X"] = true
+--------------------------------------------------
+
+if (VIDEOS["BT48X"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/bt48x.cpp",
+		MAME_DIR .. "src/devices/video/bt48x.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/imagetek_i4100.h,VIDEOS["I4100"] = true
@@ -1354,18 +1641,6 @@ if (VIDEOS["DP8510"]~=null) then
 	}
 end
 
---------------------------------------------------
---
---@src/devices/video/bt45x.h,VIDEOS["BT45X"] = true
---------------------------------------------------
-
-if (VIDEOS["BT45X"]~=null) then
-	files {
-		MAME_DIR .. "src/devices/video/bt45x.cpp",
-		MAME_DIR .. "src/devices/video/bt45x.h",
-	}
-end
-
 --------------------------------------------------
 --
 --@src/devices/video/topcat.h,VIDEOS["TOPCAT"] = true
@@ -1422,41 +1697,6 @@ if (VIDEOS["PS2GS"]~=null) then
 	}
 end
 
---------------------------------------------------
---
---@src/devices/video/decsfb.h,VIDEOS["DECSFB"] = true
---------------------------------------------------
-if (VIDEOS["DECSFB"]~=null) then
-	files {
-		MAME_DIR .. "src/devices/video/decsfb.cpp",
-		MAME_DIR .. "src/devices/video/decsfb.h",
-	}
-end
-
---------------------------------------------------
---
---@src/devices/video/bt47x.h,VIDEOS["BT47X"] = true
---------------------------------------------------
-
-if (VIDEOS["BT47X"]~=null) then
-	files {
-		MAME_DIR .. "src/devices/video/bt47x.cpp",
-		MAME_DIR .. "src/devices/video/bt47x.h",
-	}
-end
-
---------------------------------------------------
---
---@src/devices/video/bt431.h,VIDEOS["BT431"] = true
---------------------------------------------------
-
-if (VIDEOS["BT431"]~=null) then
-	files {
-		MAME_DIR .. "src/devices/video/bt431.cpp",
-		MAME_DIR .. "src/devices/video/bt431.h",
-	}
-end
-
 --------------------------------------------------
 --
 --@src/devices/video/vrender0.h,VIDEOS["VRENDER0"] = true
@@ -1493,6 +1733,18 @@ if (VIDEOS["X1_001"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/zr36060.h,VIDEOS["ZR36060"] = true
+--------------------------------------------------
+
+if (VIDEOS["ZR36060"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/zr36060.cpp",
+		MAME_DIR .. "src/devices/video/zr36060.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/zr36110.h,VIDEOS["ZR36110"] = true
@@ -1504,3 +1756,39 @@ if (VIDEOS["ZR36110"]~=null) then
 		MAME_DIR .. "src/devices/video/zr36110.h",
 	}
 end
+
+--------------------------------------------------
+--
+--@src/devices/video/bt450.h,VIDEOS["BT450"] = true
+--------------------------------------------------
+
+if (VIDEOS["BT450"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/bt450.cpp",
+		MAME_DIR .. "src/devices/video/bt450.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/st7626.h,VIDEOS["ST7626"] = true
+--------------------------------------------------
+
+if (VIDEOS["ST7626"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/st7626.cpp",
+		MAME_DIR .. "src/devices/video/st7626.h",
+	}
+end
+
+--------------------------------------------------
+--
+--@src/devices/video/serialvfd.h,VIDEOS["SERIALVFD"] = true
+--------------------------------------------------
+
+if (VIDEOS["SERIALVFD"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/serialvfd.cpp",
+		MAME_DIR .. "src/devices/video/serialvfd.h",
+	}
+end
