@@ -665,11 +665,11 @@ uint8_t pc8801_state::port40_r()
  */
 void pc8801_state::port40_w(uint8_t data)
 {
-	// TODO: merge with PC8001
+	// TODO: merge (and fix) from pc8001.cpp
 	m_centronics->write_strobe(BIT(data, 0));
 
-	m_rtc->stb_w((data & 2) >> 1);
-	m_rtc->clk_w((data & 4) >> 2);
+	m_rtc->stb_w(BIT(data, 1));
+	m_rtc->clk_w(BIT(data, 2));
 
 	if(((m_device_ctrl_data & 0x20) == 0x00) && ((data & 0x20) == 0x20))
 		m_beeper->set_state(1);
@@ -814,7 +814,7 @@ void pc8801_state::palram_w(offs_t offset, uint8_t data)
 	// p8suite Analog RGB test cross bars (reportedly works in 24 kHz / 80 column only)
 	// NB: it uses a bunch of non-waitstate related opcodes to cycle time it right,
 	// implying a stress-test for Z80 opcode cycles.
-//  m_screen->update_partial(m_screen->vpos());
+	m_screen->update_partial(m_screen->vpos());
 }
 
 
@@ -898,17 +898,6 @@ template <unsigned kanji_level> void pc8801_state::kanji_w(offs_t offset, uint8_
 	// https://retrocomputerpeople.web.fc2.com/machines/nec/8801/io_map88.html
 }
 
-#if 0
-void pc8801_state::rtc_w(uint8_t data)
-{
-	m_rtc->c0_w((data & 1) >> 0);
-	m_rtc->c1_w((data & 2) >> 1);
-	m_rtc->c2_w((data & 4) >> 2);
-	m_rtc->data_in_w((data & 8) >> 3);
-
-	// TODO: remaining bits
-}
-#endif
 
 /*
  * PC8801FH overrides (CPU clock switch)
@@ -1020,7 +1009,7 @@ void pc8801_state::main_io(address_map &map)
 //  map(0x90, 0x9f) PC-8801-31 CD-ROM i/f (8801MC)
 //  map(0xa0, 0xa3) GSX-8800 or network board
 //  map(0xa8, 0xad).rw expansion OPN (Sound Board) or OPNA (Sound Board II)
-//  map(0xb0, 0xb3) General purpose parallel I/O (i8255?)
+//  map(0xb0, 0xb3) General Purpose I/O
 //  map(0xb4, 0xb4) PC-8801-17 Video art board
 //  map(0xb5, 0xb5) PC-8801-18 Video digitizing unit
 //  map(0xbc, 0xbf) External mini floppy disk I/F (i8255), PC-8801-13 / -20 / -22
@@ -1297,8 +1286,8 @@ static INPUT_PORTS_START( pc8801 )
 	PORT_DIPNAME( 0x08, 0x00, "Auto-boot floppy at start-up" )
 	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-//  PORT_BIT( 0x10, IP_ACTIVE_HIGH,IPT_CUSTOM ) PORT_READ_LINE_DEVICE_MEMBER("upd1990a", upd1990a_device, data_out_r)
-//  PORT_BIT( 0x20, IP_ACTIVE_HIGH,IPT_CUSTOM ) PORT_VBLANK("screen")
+//  PORT_BIT( 0x10, IP_ACTIVE_HIGH,IPT_CUSTOM ) PORT_READ_LINE_DEVICE_MEMBER("upd1990a", FUNC(upd1990a_device::data_out_r))
+//  PORT_BIT( 0x20, IP_ACTIVE_HIGH,IPT_CUSTOM ) PORT_READ_LINE_DEVICE_MEMBER("screen", FUNC(screen_device::vblank))
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	// TODO: Coming from the old legacy driver as "EXSWITCH", where this maps?
@@ -1547,12 +1536,12 @@ void pc8801mk2sr_state::opn_portb_w(uint8_t data)
 }
 
 // Cassette Configuration
-WRITE_LINE_MEMBER( pc8801_state::txdata_callback )
+void pc8801_state::txdata_callback(int state)
 {
 	//m_cassette->output( (state) ? 1.0 : -1.0);
 }
 
-WRITE_LINE_MEMBER( pc8801_state::rxrdy_irq_w )
+void pc8801_state::rxrdy_irq_w(int state)
 {
 	if (state)
 		assert_irq(RXRDY_IRQ_LEVEL);
@@ -1580,7 +1569,7 @@ IRQ_CALLBACK_MEMBER(pc8801_state::int_ack_cb)
 	return (7 - level) * 2;
 }
 
-WRITE_LINE_MEMBER(pc8801_state::int4_irq_w)
+void pc8801_state::int4_irq_w(int state)
 {
 	bool irq_state = m_sound_irq_enable & state;
 
@@ -1594,7 +1583,7 @@ WRITE_LINE_MEMBER(pc8801_state::int4_irq_w)
 	m_sound_irq_pending = state;
 }
 
-// FIXME: convert to pure WRITE_LINE_MEMBER
+// FIXME: convert to pure write-line-style member
 // Works with 0 -> 1 F/F transitions
 TIMER_DEVICE_CALLBACK_MEMBER(pc8801_state::clock_irq_w)
 {
@@ -1629,7 +1618,7 @@ void pc8801_state::assert_irq(u8 level)
 		m_irq_state.pending |= mask;
 }
 
-WRITE_LINE_MEMBER(pc8801_state::vrtc_irq_w)
+void pc8801_state::vrtc_irq_w(int state)
 {
 //  bool irq_state = m_vrtc_irq_enable & state;
 	if (state)
@@ -1638,7 +1627,7 @@ WRITE_LINE_MEMBER(pc8801_state::vrtc_irq_w)
 	}
 }
 
-WRITE_LINE_MEMBER(pc8801_state::irq_w)
+void pc8801_state::irq_w(int state)
 {
 	m_maincpu->set_input_line(0, state ? ASSERT_LINE : CLEAR_LINE);
 }
@@ -1717,18 +1706,16 @@ void pc8801_state::pc8801(machine_config &config)
 
 	// Note: original models up to OPNA variants really have an internal mono speaker,
 	// but user eventually can have a stereo mixing audio card mounted so for simplicity we MCM here.
-	SPEAKER(config, m_lspeaker).front_left();
-	SPEAKER(config, m_rspeaker).front_right();
+	SPEAKER(config, m_speaker, 2).front();
 
 	// TODO: DAC_1BIT
 	// 2400 Hz according to schematics, unaffected by clock speed setting (confirmed on real HW)
 	BEEP(config, m_beeper, MASTER_CLOCK / 16 / 13 / 8);
 
-	for (auto &speaker : { m_lspeaker, m_rspeaker })
-	{
-		m_cassette->add_route(ALL_OUTPUTS, speaker, 0.025);
-		m_beeper->add_route(ALL_OUTPUTS, speaker, 0.10);
-	}
+	m_cassette->add_route(ALL_OUTPUTS, m_speaker, 0.025, 0);
+	m_cassette->add_route(ALL_OUTPUTS, m_speaker, 0.025, 1);
+	m_beeper->add_route(ALL_OUTPUTS, m_speaker, 0.10, 0);
+	m_beeper->add_route(ALL_OUTPUTS, m_speaker, 0.10, 1);
 
 	MSX_GENERAL_PURPOSE_PORT(config, m_mouse_port, msx_general_purpose_port_devices, "joystick");
 
@@ -1749,14 +1736,15 @@ void pc8801mk2sr_state::pc8801mk2sr(machine_config &config)
 	m_opn->port_b_read_callback().set(FUNC(pc8801mk2sr_state::opn_portb_r));
 	m_opn->port_b_write_callback().set(FUNC(pc8801mk2sr_state::opn_portb_w));
 
-	for (auto &speaker : { m_lspeaker, m_rspeaker })
-	{
-		// TODO: per-channel mixing is unconfirmed
-		m_opn->add_route(0, speaker, 0.125);
-		m_opn->add_route(1, speaker, 0.125);
-		m_opn->add_route(2, speaker, 0.125);
-		m_opn->add_route(3, speaker, 0.125);
-	}
+	// TODO: per-channel mixing is unconfirmed
+	m_opn->add_route(0, m_speaker, 0.125, 0);
+	m_opn->add_route(1, m_speaker, 0.125, 0);
+	m_opn->add_route(2, m_speaker, 0.125, 0);
+	m_opn->add_route(3, m_speaker, 0.125, 0);
+	m_opn->add_route(0, m_speaker, 0.125, 1);
+	m_opn->add_route(1, m_speaker, 0.125, 1);
+	m_opn->add_route(2, m_speaker, 0.125, 1);
+	m_opn->add_route(3, m_speaker, 0.125, 1);
 }
 
 void pc8801mk2sr_state::pc8801mk2mr(machine_config &config)
@@ -1779,10 +1767,10 @@ void pc8801fh_state::pc8801fh(machine_config &config)
 	m_opna->port_b_write_callback().set(FUNC(pc8801fh_state::opn_portb_w));
 
 	// TODO: per-channel mixing is unconfirmed
-	m_opna->add_route(0, m_lspeaker, 0.25);
-	m_opna->add_route(0, m_rspeaker, 0.25);
-	m_opna->add_route(1, m_lspeaker, 0.75);
-	m_opna->add_route(2, m_rspeaker, 0.75);
+	m_opna->add_route(0, m_speaker, 0.75, 0);
+	m_opna->add_route(0, m_speaker, 0.75, 1);
+	m_opna->add_route(1, m_speaker, 0.75, 0);
+	m_opna->add_route(2, m_speaker, 0.75, 1);
 
 	// TODO: add possible configuration override for baudrate here
 	// ...
@@ -2025,6 +2013,7 @@ ROM_END
 
 
 COMP( 1981, pc8801,      0,      0,      pc8801,      pc8801, pc8801_state, empty_init,      "NEC",   "PC-8801",       MACHINE_NOT_WORKING | MACHINE_IMPERFECT_TIMING | MACHINE_IMPERFECT_GRAPHICS )
+// PC-8801A (120V, USA & Canada) / PC-8801B (240V, Export?) for Western markets according to a NEC brochure
 COMP( 1983, pc8801mk2,   pc8801, 0,      pc8801,      pc8801, pc8801_state, empty_init,      "NEC",   "PC-8801mkII",   MACHINE_NOT_WORKING | MACHINE_IMPERFECT_TIMING | MACHINE_IMPERFECT_GRAPHICS )
 
 // internal OPN
