@@ -245,9 +245,8 @@ uint16_t md_base_state::m68k_version_read()
 	  D0 : Bit 0 of version number
 	*/
 	LOG("%s: read version register\n", machine().describe_context());
-	// Version number contained in bits 3-0
-	// TODO: non-TMSS BIOSes must return 0 here
-	uint16_t const retdata = m_version_hi_nibble | 0x01;
+	// Version number contained in bits 3-0 (TMSS)
+	uint16_t const retdata = m_version_hi_nibble | m_version_lo_nibble;
 
 	return retdata | (retdata << 8);
 }
@@ -441,21 +440,17 @@ uint16_t md_base_state::megadriv_68k_check_z80_bus(offs_t offset, uint16_t mem_m
 TIMER_CALLBACK_MEMBER(md_base_state::megadriv_z80_run_state)
 {
 	/* Is the z80 RESET line pulled? */
-	// TODO: Z80 /RESET
 	if (m_genz80.z80_is_reset)
 	{
-		m_z80snd->reset();
-		m_z80snd->suspend(SUSPEND_REASON_HALT, 1);
+		m_z80snd->set_input_line(INPUT_LINE_RESET, ASSERT_LINE);
 		m_ymsnd->reset();
 	}
 	else
 	{
+		m_z80snd->set_input_line(INPUT_LINE_RESET, CLEAR_LINE);
+
 		/* Check if z80 has the bus */
-		// TODO: Z80 /BUSREQ
-		if (m_genz80.z80_has_bus)
-			m_z80snd->resume(SUSPEND_REASON_HALT);
-		else
-			m_z80snd->suspend(SUSPEND_REASON_HALT, 1);
+		m_z80snd->set_input_line(Z80_INPUT_LINE_BUSRQ, m_genz80.z80_has_bus ? CLEAR_LINE : ASSERT_LINE);
 	}
 }
 
@@ -725,7 +720,7 @@ void md_base_state::megadriv_stop_scanline_timer()
 
 
 // this comes from the VDP on lines 240 (on) 241 (off) and is connected to the z80 irq 0
-WRITE_LINE_MEMBER(md_base_state::vdp_sndirqline_callback_genesis_z80)
+void md_base_state::vdp_sndirqline_callback_genesis_z80(int state)
 {
 	if (state == ASSERT_LINE)
 	{
@@ -739,7 +734,7 @@ WRITE_LINE_MEMBER(md_base_state::vdp_sndirqline_callback_genesis_z80)
 }
 
 // this comes from the vdp, and is connected to 68k irq level 6 (main vbl interrupt)
-WRITE_LINE_MEMBER(md_core_state::vdp_lv6irqline_callback_genesis_68k)
+void md_core_state::vdp_lv6irqline_callback_genesis_68k(int state)
 {
 	if (state == ASSERT_LINE)
 		m_maincpu->set_input_line(6, HOLD_LINE);
@@ -748,7 +743,7 @@ WRITE_LINE_MEMBER(md_core_state::vdp_lv6irqline_callback_genesis_68k)
 }
 
 // this comes from the vdp, and is connected to 68k irq level 4 (raster interrupt)
-WRITE_LINE_MEMBER(md_core_state::vdp_lv4irqline_callback_genesis_68k)
+void md_core_state::vdp_lv4irqline_callback_genesis_68k(int state)
 {
 	if (state == ASSERT_LINE)
 		m_maincpu->set_input_line(4, HOLD_LINE);
@@ -884,16 +879,15 @@ void md_base_state::md_ntsc(machine_config &config)
 	megadriv_ioports(config);
 
 	m_vdp->snd_irq().set(FUNC(md_base_state::vdp_sndirqline_callback_genesis_z80));
-	m_vdp->add_route(ALL_OUTPUTS, "lspeaker", 0.50);
-	m_vdp->add_route(ALL_OUTPUTS, "rspeaker", 0.50);
+	m_vdp->add_route(ALL_OUTPUTS, "speaker", 0.50, 0);
+	m_vdp->add_route(ALL_OUTPUTS, "speaker", 0.50, 1);
 
 	// sound hardware
-	SPEAKER(config, "lspeaker").front_left();
-	SPEAKER(config, "rspeaker").front_right();
+	SPEAKER(config, "speaker", 2).front();
 
 	YM2612(config, m_ymsnd, MASTER_CLOCK_NTSC / 7); // 7.67 MHz
-	m_ymsnd->add_route(0, "lspeaker", 0.50);
-	m_ymsnd->add_route(1, "rspeaker", 0.50);
+	m_ymsnd->add_route(0, "speaker", 0.50, 0);
+	m_ymsnd->add_route(1, "speaker", 0.50, 1);
 }
 
 void md_base_state::md2_ntsc(machine_config &config)
@@ -902,8 +896,8 @@ void md_base_state::md2_ntsc(machine_config &config)
 
 	// Internalized YM3438 in VDP ASIC
 	YM3438(config.replace(), m_ymsnd, MASTER_CLOCK_NTSC / 7); // 7.67 MHz
-	m_ymsnd->add_route(0, "lspeaker", 0.50);
-	m_ymsnd->add_route(1, "rspeaker", 0.50);
+	m_ymsnd->add_route(0, "speaker", 0.50, 0);
+	m_ymsnd->add_route(1, "speaker", 0.50, 1);
 }
 
 /************ PAL hardware has a different master clock *************/
@@ -923,16 +917,15 @@ void md_base_state::md_pal(machine_config &config)
 	megadriv_ioports(config);
 
 	m_vdp->snd_irq().set(FUNC(md_base_state::vdp_sndirqline_callback_genesis_z80));
-	m_vdp->add_route(ALL_OUTPUTS, "lspeaker", 0.50);
-	m_vdp->add_route(ALL_OUTPUTS, "rspeaker", 0.50);
+	m_vdp->add_route(ALL_OUTPUTS, "speaker", 0.50, 0);
+	m_vdp->add_route(ALL_OUTPUTS, "speaker", 0.50, 1);
 
 	// sound hardware
-	SPEAKER(config, "lspeaker").front_left();
-	SPEAKER(config, "rspeaker").front_right();
+	SPEAKER(config, "speaker", 2).front();
 
 	YM2612(config, m_ymsnd, MASTER_CLOCK_PAL / 7); // 7.67 MHz
-	m_ymsnd->add_route(0, "lspeaker", 0.50);
-	m_ymsnd->add_route(1, "rspeaker", 0.50);
+	m_ymsnd->add_route(0, "speaker", 0.50, 0);
+	m_ymsnd->add_route(1, "speaker", 0.50, 1);
 }
 
 void md_base_state::md2_pal(machine_config &config)
@@ -941,8 +934,8 @@ void md_base_state::md2_pal(machine_config &config)
 
 	// Internalized YM3438 in VDP ASIC
 	YM3438(config.replace(), m_ymsnd, MASTER_CLOCK_PAL / 7); /* 7.67 MHz */
-	m_ymsnd->add_route(0, "lspeaker", 0.50);
-	m_ymsnd->add_route(1, "rspeaker", 0.50);
+	m_ymsnd->add_route(0, "speaker", 0.50, 0);
+	m_ymsnd->add_route(1, "speaker", 0.50, 1);
 }
 
 
@@ -962,6 +955,8 @@ void md_base_state::megadriv_init_common()
 	save_pointer(NAME(m_genz80.z80_prgram), 0x2000);
 
 	m_maincpu->set_tas_write_callback(*this, FUNC(md_base_state::megadriv_tas_callback));
+
+	m_version_lo_nibble = 0;
 }
 
 void md_base_state::init_megadriv()
@@ -1003,7 +998,7 @@ void md_base_state::init_megadrie()
 	m_version_hi_nibble = 0xe0; // Export PAL no-SCD
 }
 
-WRITE_LINE_MEMBER(md_core_state::screen_vblank_megadriv)
+void md_core_state::screen_vblank_megadriv(int state)
 {
 	if (m_io_reset.read_safe(0) & 0x01)
 		m_maincpu->pulse_input_line(INPUT_LINE_RESET, attotime::zero);
