@@ -101,8 +101,7 @@ public:
 		m_dac(*this, "dac"),
 		m_soundlatch(*this, "soundlatch"),
 		m_gfxdecode(*this, "gfxdecode"),
-		m_palette(*this, "palette"),
-		m_watchdog(*this, "watchdog")
+		m_palette(*this, "palette")
 	{ }
 
 	void looping(machine_config &config);
@@ -110,44 +109,43 @@ public:
 	void init_looping();
 
 protected:
-	virtual void machine_start() override;
-	virtual void machine_reset() override;
-	virtual void video_start() override;
+	virtual void machine_start() override ATTR_COLD;
+	virtual void machine_reset() override ATTR_COLD;
+	virtual void video_start() override ATTR_COLD;
 
 private:
-	DECLARE_WRITE_LINE_MEMBER(flip_screen_x_w);
-	DECLARE_WRITE_LINE_MEMBER(flip_screen_y_w);
+	void flip_screen_x_w(int state);
+	void flip_screen_y_w(int state);
 	void videoram_w(offs_t offset, uint8_t data);
 	void colorram_w(offs_t offset, uint8_t data);
-	DECLARE_WRITE_LINE_MEMBER(level2_irq_set);
-	DECLARE_WRITE_LINE_MEMBER(main_irq_ack_w);
-	DECLARE_WRITE_LINE_MEMBER(watchdog_w);
-	DECLARE_WRITE_LINE_MEMBER(souint_clr);
-	DECLARE_WRITE_LINE_MEMBER(ballon_enable_w);
+	void level2_irq_set(int state);
+	void main_irq_ack_w(int state);
+	void souint_clr(int state);
+	void ballon_enable_w(int state);
 	void out_0_w(uint8_t data);
 	void out_2_w(uint8_t data);
 	uint8_t adc_r();
 	void adc_w(uint8_t data);
-	DECLARE_WRITE_LINE_MEMBER(plr2_w);
+	void plr2_w(int state);
 	uint8_t cop_unk_r();
-	DECLARE_READ_LINE_MEMBER(cop_serial_r);
+	int cop_serial_r();
 	void cop_l_w(uint8_t data);
 	uint8_t protection_r();
-	[[maybe_unused]] DECLARE_WRITE_LINE_MEMBER(spcint);
-	DECLARE_WRITE_LINE_MEMBER(int_update);
+	[[maybe_unused]] void spcint(int state);
+	void int_update(int state);
 	void sound_sw(uint8_t data);
-	DECLARE_WRITE_LINE_MEMBER(ay_enable_w);
-	DECLARE_WRITE_LINE_MEMBER(speech_enable_w);
+	void ay_enable_w(int state);
+	void speech_enable_w(int state);
 	TILE_GET_INFO_MEMBER(get_tile_info);
 	void palette(palette_device &palette) const;
 	uint32_t screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(interrupt);
 	void draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect);
 
-	void io_map(address_map &map);
-	void map(address_map &map);
-	void sound_io_map(address_map &map);
-	void sound_map(address_map &map);
+	void io_map(address_map &map) ATTR_COLD;
+	void map(address_map &map) ATTR_COLD;
+	void sound_io_map(address_map &map) ATTR_COLD;
+	void sound_map(address_map &map) ATTR_COLD;
 
 	// memory pointers
 	required_shared_ptr<uint8_t> m_videoram;
@@ -166,7 +164,6 @@ private:
 	required_device<generic_latch_8_device> m_soundlatch;
 	required_device<gfxdecode_device> m_gfxdecode;
 	required_device<palette_device> m_palette;
-	required_device<watchdog_timer_device> m_watchdog;
 };
 
 
@@ -244,14 +241,14 @@ void looping_state::video_start()
  *
  *************************************/
 
-WRITE_LINE_MEMBER(looping_state::flip_screen_x_w)
+void looping_state::flip_screen_x_w(int state)
 {
 	flip_screen_x_set(!state);
 	m_bg_tilemap->set_scrollx(0, flip_screen() ? 128 : 0);
 }
 
 
-WRITE_LINE_MEMBER(looping_state::flip_screen_y_w)
+void looping_state::flip_screen_y_w(int state)
 {
 	flip_screen_y_set(!state);
 	m_bg_tilemap->set_scrollx(0, flip_screen() ? 256 : 0);
@@ -361,7 +358,7 @@ INTERRUPT_GEN_MEMBER(looping_state::interrupt)
 }
 
 
-WRITE_LINE_MEMBER(looping_state::level2_irq_set)
+void looping_state::level2_irq_set(int state)
 {
 	logerror("Level 2 int = %d\n", state);
 	if (state == 0)
@@ -369,19 +366,14 @@ WRITE_LINE_MEMBER(looping_state::level2_irq_set)
 }
 
 
-WRITE_LINE_MEMBER(looping_state::main_irq_ack_w)
+void looping_state::main_irq_ack_w(int state)
 {
 	if (state == 0)
 		m_maincpu->set_input_line(INT_9995_INT1, CLEAR_LINE);
 }
 
-WRITE_LINE_MEMBER(looping_state::watchdog_w)
-{
-	m_watchdog->watchdog_reset();
-}
 
-
-WRITE_LINE_MEMBER(looping_state::souint_clr)
+void looping_state::souint_clr(int state)
 {
 	logerror("Soundint clr = %d\n", state);
 	if (state == 0)
@@ -389,14 +381,14 @@ WRITE_LINE_MEMBER(looping_state::souint_clr)
 }
 
 
-WRITE_LINE_MEMBER(looping_state::spcint)
+void looping_state::spcint(int state)
 {
 	logerror("Speech /int = %d\n", state == ASSERT_LINE ? 1 : 0);
 	m_audiocpu->set_input_line(INT_9980A_LEVEL4, state == ASSERT_LINE ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
-WRITE_LINE_MEMBER(looping_state::int_update)
+void looping_state::int_update(int state)
 {
 	// hack necessitated by flawed input logic in TMS9980A core
 	if (m_soundlatch->pending_r())
@@ -438,20 +430,20 @@ void looping_state::sound_sw(uint8_t data)
  *
  *************************************/
 
-WRITE_LINE_MEMBER(looping_state::ay_enable_w)
+void looping_state::ay_enable_w(int state)
 {
 	for (int output = 0; output < 3; output++)
 		m_aysnd->set_output_gain(output, state ? 1.0 : 0.0);
 }
 
 
-WRITE_LINE_MEMBER(looping_state::speech_enable_w)
+void looping_state::speech_enable_w(int state)
 {
 	m_tms->set_output_gain(0, state ? 1.0 : 0.0);
 }
 
 
-WRITE_LINE_MEMBER(looping_state::ballon_enable_w)
+void looping_state::ballon_enable_w(int state)
 {
 	logerror("ballon_enable_w = %d\n", state);
 }
@@ -470,7 +462,7 @@ void looping_state::out_2_w(uint8_t data) { osd_printf_debug("out2 = %02X\n", da
 uint8_t looping_state::adc_r() { osd_printf_debug("%04X:ADC read\n", m_maincpu->pc()); return 0xff; }
 void looping_state::adc_w(uint8_t data) { osd_printf_debug("%04X:ADC write = %02X\n", m_maincpu->pc(), data); }
 
-WRITE_LINE_MEMBER(looping_state::plr2_w)
+void looping_state::plr2_w(int state)
 {
 	/* set to 1 after IDLE, cleared to 0 during processing
 	   is this an LED on the PCB? */
@@ -489,7 +481,7 @@ uint8_t looping_state::cop_unk_r()
 	return 1;
 }
 
-READ_LINE_MEMBER(looping_state::cop_serial_r)
+int looping_state::cop_serial_r()
 {
 	return 1;
 }
@@ -638,9 +630,9 @@ void looping_state::looping(machine_config &config)
 	// Q4 = C0
 	// Q5 = C1
 	mainlatch.q_out_cb<6>().set(FUNC(looping_state::main_irq_ack_w));
-	mainlatch.q_out_cb<7>().set(FUNC(looping_state::watchdog_w));
+	mainlatch.q_out_cb<7>().set("watchdog", FUNC(watchdog_timer_device::reset_line_w)).invert();
 
-	WATCHDOG_TIMER(config, m_watchdog);
+	WATCHDOG_TIMER(config, "watchdog");
 
 	// video hardware
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
@@ -724,7 +716,7 @@ static INPUT_PORTS_START( looping )
 	PORT_DIPSETTING(    0x0a, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x0e, DEF_STR( 1C_7C ) )
-	PORT_DIPSETTING(    0x00, "1 Coin/10 Credits" )
+	PORT_DIPSETTING(    0x00, DEF_STR( 1C_10C ) )
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )    PORT_DIPLOCATION("DSW:4")  // Check code at 0x2c00
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
